﻿using System;
using System.Collections.Generic;
using System.Data.SqlClient;
using System.Data.SqlTypes;
using System.Linq;
using System.Web;
using DotNetNuke.Common.Utilities;
using DotNetNuke.Framework.Providers;
using Microsoft.ApplicationBlocks.Data;

namespace SINewsAndArticles.SIUsersCounter.Providers.DataProviders.SqlDataProvider
{
    public class SqlDataProvider:DataProvider
    {
        #region private Members

        private const string ProviderType = "data";
        private const string ModuleQualifier = "sasan_";

        private readonly ProviderConfiguration _providerConfiguration =
            ProviderConfiguration.GetProviderConfiguration(ProviderType);

        private readonly string _connectionString;
        private readonly string _providerPath;
        private readonly string _objectQualifier;
        private readonly string _databaseOwner;

        #endregion
        #region
        public SqlDataProvider()
        {

            // Read the configuration specific information for this provider
            Provider objProvider = (Provider)(_providerConfiguration.Providers[_providerConfiguration.DefaultProvider]);

            // Read the attributes for this provider

            //Get Connection string from web.config
            _connectionString = Config.GetConnectionString();

            if (string.IsNullOrEmpty(_connectionString))
            {
                // Use connection string specified in provider
                _connectionString = objProvider.Attributes["connectionString"];
            }

            _providerPath = objProvider.Attributes["providerPath"];

            _objectQualifier = objProvider.Attributes["objectQualifier"];
            if (!string.IsNullOrEmpty(_objectQualifier) && _objectQualifier.EndsWith("_", StringComparison.Ordinal) == false)
            {
                _objectQualifier += "_";
            }

            _databaseOwner = objProvider.Attributes["databaseOwner"];
            if (!string.IsNullOrEmpty(_databaseOwner) && _databaseOwner.EndsWith(".", StringComparison.Ordinal) == false)
            {
                _databaseOwner += ".";
            }

        }

        #endregion

        #region Properties

        public string ConnectionString
        {
            get
            {
                return _connectionString;
            }
        }

        public string ProviderPath
        {
            get
            {
                return _providerPath;
            }
        }

        public string ObjectQualifier
        {
            get
            {
                return _objectQualifier;
            }
        }

        public string DatabaseOwner
        {
            get
            {
                return _databaseOwner;
            }
        }

        // used to prefect your database objects (stored procedures, tables, views, etc)
        public string NamePrefix
        {
            get { return DatabaseOwner + ObjectQualifier; }
        }

        #endregion

        #region Private Methods

        private static object GetNull(object field)
        {
            return Null.GetNull(field, DBNull.Value);
        }

        #endregion

        #region Public Methods

        public string gettt()
        {
            return NamePrefix;
        }



        #endregion
        //Table Config
        public override int InsertUsersCounterConfig(Components.SIUsersCounterConfig ucc)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString, NamePrefix + "SIInsertUsersCounterConfig"
                , new SqlParameter("OnlineUsersPic", ucc.OnlineUsersPic)
                , new SqlParameter("DailyUsersCounter", ucc.DailyUsersCounter)
                , new SqlParameter("fullUsersCounter", ucc.fullUsersCounter)
                , new SqlParameter("OnlineUsersLabel", ucc.OnlineUsersLabel)
                , new SqlParameter("DailyUsersCounterLabel", ucc.DailyUsersCounterLabel)
                , new SqlParameter("fullUsersCounterLable", ucc.fullUsersCounterLable));
        }

        public override int SIDeleteUsersCounterConfig(int Id)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString, NamePrefix + "SIDeleteUsersCounterConfig",
                new SqlParameter("Id", Id));
        }

        public override int SIUpdateUsersCounterConfig(int Id, Components.SIUsersCounterConfig uss)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString, NamePrefix + "SIUpdateUsersCounterConfig"
                , new SqlParameter("Id", Id)
                , new SqlParameter("OnlineUsersPic", uss.OnlineUsersPic)
                , new SqlParameter("DailyUsersCounter", uss.DailyUsersCounter)
                , new SqlParameter("fullUsersCounter", uss.fullUsersCounter)
                , new SqlParameter("OnlineUsersLabel", uss.OnlineUsersLabel)
                , new SqlParameter("DailyUsersCounterLabel", uss.DailyUsersCounterLabel)
                , new SqlParameter("fullUsersCounterLable", uss.fullUsersCounterLable));
        }

        public override System.Data.IDataReader SISelectByIdUsersCounterConfig(int ID)
        {
            return SqlHelper.ExecuteReader(ConnectionString, NamePrefix + "SISelectByIdUsersCounterConfig",
                new SqlParameter("SISelectByIdUsersCounterConfig", ID));
        }

        public override System.Data.IDataReader SISelectALlIdUsersCounterConfig()
        {
            return SqlHelper.ExecuteReader(ConnectionString, NamePrefix + "SISelectALlIdUsersCounterConfig");
        }
        //Table login User 
        public override System.Data.IDataReader SISelectByIdtUsersCounterLogins(int id)
        {
            return SqlHelper.ExecuteReader(ConnectionString, NamePrefix + "SISelectByIdtUsersCounterLogins"
                , new SqlParameter("Id", id));
        }

        public override int SIInsertUsersCounterLogins(Components.SIUsersCounterLogins ul)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString, NamePrefix + "SIInsertUsersCounterLogins"
                , new SqlParameter("UserId", ul.UserId)
                , new SqlParameter("ComeInDateTime", ul.ComeInDateTime)
                , new SqlParameter("GoOutDateTime", ul.GoOutDateTime)
                , new SqlParameter("UserOS", ul.UserOS)
                , new SqlParameter("UserBrowser", ul.UserBrowser)
                , new SqlParameter("UserResolution", ul.UserResolution)
                , new SqlParameter("SessinID", ul.SessionID));
        }

        public override int SIDeleteByIdtUsersCounterLogins(int id)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString, NamePrefix + "SIDeleteByIdtUsersCounterLogins",
                new SqlParameter("Id", id));
        }

        public override System.Data.IDataReader SISelectBetweenDatesUsersCounterLogins(DateTime BeginDateTime, DateTime EndDateTime)
        {
            return SqlHelper.ExecuteReader(ConnectionString, NamePrefix + "SISelectBetweenDatesUsersCounterLogins"
                , new SqlParameter("BeginDateTime", BeginDateTime)
                , new SqlParameter("EndDateTime", EndDateTime));
        }

        public override int SISelectBetweenDatesCountUsersCounterLogins(DateTime BeginDateTime, DateTime EndDateTime)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString,
                NamePrefix + "SISelectBetweenDatesCountUsersCounterLogins"
                , new SqlParameter("BeginDateTime", BeginDateTime)
                , new SqlParameter("EndDateTime", EndDateTime));
        }

        public override System.Data.IDataReader SISelectByInDateUsersCounterLogins(DateTime InDate)
        {
            return SqlHelper.ExecuteReader(ConnectionString, NamePrefix + "SISelectByInDateUsersCounterLogins"
                , new SqlParameter("InDate", InDate));
        }

        public override int SISelectByInDateCountUsersCounterLogins(DateTime InDate)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString, NamePrefix + "SISelectByInDateCountUsersCounterLogins",
                new SqlParameter("InDate", InDate));
        }

        public override int SIUpdatetUsersCounterLogins(int id, Components.SIUsersCounterLogins ul)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString, NamePrefix + "SIUpdatetUsersCounterLogins"
                , new SqlParameter("Id", id)
                , new SqlParameter("UserId", ul.UserId)
                , new SqlParameter("ComeInDateTime", ul.ComeInDateTime)
                , new SqlParameter("GoOutDateTime", ul.GoOutDateTime)
                , new SqlParameter("UserOS", ul.UserOS)
                , new SqlParameter("UserBrowser", ul.UserBrowser)
                , new SqlParameter("UserResolution", ul.UserResolution)
                , new SqlParameter("sessionID", ul.SessionID));
        }

        public override System.Data.IDataReader SISelectAllUsersCounterLogins()
        {
            return SqlHelper.ExecuteReader(ConnectionString, NamePrefix + "SISelectAllUsersCounterLogins")
                ;
        }

        public override System.Data.IDataReader SISelectToDatesUsersCounterLogins(DateTime EndDate)
        {
            return SqlHelper.ExecuteReader(ConnectionString, NamePrefix + "SISelectToDatesUsersCounterLogins"
                , new SqlParameter("EndDate", EndDate));
        }

        public override int SISelectToDatesCountUsersCounterLogins(DateTime EndDate)
        {
            return SqlHelper.ExecuteNonQuery(ConnectionString, NamePrefix + "SISelectToDatesCountUsersCounterLogins"
                , new SqlParameter("EndDate", EndDate));
        }

        public override System.Data.IDataReader SISelectBySessionIDCounterLogins(string SessionID)
        {
            return SqlHelper.ExecuteReader(ConnectionString, NamePrefix + "SISelectBySessionIDCounterLogins"
                , new SqlParameter("sessionID", SessionID));
        }
    }
}